MatchedTokensScoring class

Applies a boost for matched tokens, but adjusts the boost based on whether the term is an exact match, a prefix match, or a contains match

Inheritance

Constructors

MatchedTokensScoring([Boost matchedTokenBoost = const Boost.amount(1, "tokenPrefix")])
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchedTokenBoost → Boost
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scoreTerm(FullTextSearch search, TermSearchResult term, Score current) → void
Inspects a matched term term and appends a score to current. The scores are calculated after all scorers have run, at which point the amount values are summed up, and then the percent multipliers are applied
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited