TermSearchResult<T> class

Implemented types

Constructors

TermSearchResult(T result, Set<String> matchedTerms, Set<TermMatch> matchedTokens, bool matchAll)

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchAll → bool
final
matchedTerms → Set<String>
The search terms that were successfully matched. For "fuzzy" matches, you may only match one out of 3 terms, eg. user types: George Harrison ate pizza we matched: George Jones ate chips matchedTerms = George, ate
final
matchedTokens → Set<TermMatch>
The tokens that were successfully matched. user types: George Harrison ate pizza we tokenized: My mate George Jones threw poker chips in Georgetown with his wife Atena. matchedTerms = George, ate matchedTokens = Georgetown, Atena, George, mate
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
result → T
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → Score
final
scoreValue → double
no setter
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

compareTo(TermSearchResult<T> lhs) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited