compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(lhs) {
if (lhs is TermSearchResult<T>) {
final rhs = this;
if (lhs == rhs) return 0;
var scoreA = rhs.scoreValue;
var scoreB = lhs.scoreValue;
if (scoreA == 0 && scoreB == 0) return 1;
return scoreB.compareTo(scoreA);
} else {
return -1;
}
}