TokenCheck class

Constructors

TokenCheck.check(String searchTerm, FTSToken tokenToCheck)
const
TokenCheck.result(String searchTerm, FTSToken tokenToCheck, TokenCheckResult? result)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
result → TokenCheckResult?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTerm → String
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tokenToCheck → FTSToken
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withResult(TokenCheckResult result) → TokenCheck

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator >(dynamic other) → bool